@@ -2,17 +2,19 @@
 #
 #
 
-from akamai.edgegrid import EdgeGridAuth
 from collections import defaultdict
 from logging import getLogger
-from requests import Session
 from urllib.parse import urljoin
 
-from octodns.record import Record
+from akamai.edgegrid import EdgeGridAuth
+from requests import Session
+
+from octodns import __VERSION__ as octodns_version
 from octodns.provider import ProviderException
 from octodns.provider.base import BaseProvider
+from octodns.record import Record
 
-__VERSION__ = '0.0.2'
+__VERSION__ = '0.0.3'
 
 
 class AkamaiClientNotFound(ProviderException):
@@ -34,10 +36,14 @@ class AkamaiClient(object):
     '''
 
     def __init__(self, client_secret, host, access_token, client_token):
-
         self.base = "https://" + host + "/config-dns/v2/"
 
         sess = Session()
+        sess.headers.update(
+            {
+                'User-Agent': f'octodns/{octodns_version} octodns-edgedns/{__VERSION__}'
+            }
+        )
         sess.auth = EdgeGridAuth(
             client_token=client_token,
             client_secret=client_secret,
@@ -46,7 +52,6 @@ class AkamaiClient(object):
         self._sess = sess
 
     def _request(self, method, path, params=None, data=None, v1=False):
-
         url = urljoin(self.base, path)
         resp = self._sess.request(method, url, params=params, json=data)
 
@@ -100,7 +105,6 @@ class AkamaiClient(object):
         sortBy="name",
         types=None,
     ):
-
         params = {
             'page': page,
             'pageSize': pageSize,
@@ -125,6 +129,7 @@ class AkamaiProvider(BaseProvider):
         (
             'A',
             'AAAA',
+            'CAA',
             'CNAME',
             'MX',
             'NAPTR',
@@ -149,7 +154,6 @@ class AkamaiProvider(BaseProvider):
         *args,
         **kwargs,
     ):
-
         self.log = getLogger(f'AkamaiProvider[{id}]')
         self.log.debug('__init__: id=%s, ')
         super().__init__(id, *args, **kwargs)
@@ -182,7 +186,6 @@ class AkamaiProvider(BaseProvider):
 
         values = defaultdict(lambda: defaultdict(list))
         for record in self.zone_records(zone):
-
             _type = record.get('type')
             # Akamai sends down prefix.zonename., while octodns expects prefix
             _name = record.get('name').split("." + zone.name[:-1], 1)[0]
@@ -234,7 +237,6 @@ class AkamaiProvider(BaseProvider):
         self._zone_records.pop(desired.name, None)
 
     def _apply_Create(self, change):
-
         new = change.new
         record_type = new._type
 
@@ -257,7 +259,6 @@ class AkamaiProvider(BaseProvider):
         return
 
     def _apply_Delete(self, change):
-
         zone = change.existing.zone.name[:-1]
         name = self._set_full_name(change.existing.name, zone)
         record_type = change.existing._type
@@ -267,7 +268,6 @@ class AkamaiProvider(BaseProvider):
         return
 
     def _apply_Update(self, change):
-
         new = change.new
         record_type = new._type
 
@@ -290,7 +290,6 @@ class AkamaiProvider(BaseProvider):
         return
 
     def _data_for_multiple(self, _type, records):
-
         return {
             'ttl': records['ttl'],
             'type': _type,
@@ -303,6 +302,13 @@ class AkamaiProvider(BaseProvider):
     _data_for_PTR = _data_for_multiple
     _data_for_SPF = _data_for_multiple
 
+    def _data_for_CAA(self, _type, records):
+        values = []
+        for r in records['rdata']:
+            flags, tag, value = r.split(" ", 2)
+            values.append({'flags': flags, 'tag': tag, 'value': value})
+        return {'ttl': records['ttl'], 'type': _type, 'values': values}
+
     def _data_for_CNAME(self, _type, records):
         value = records['rdata'][0]
         if value[-1] != '.':
@@ -384,6 +390,17 @@ class AkamaiProvider(BaseProvider):
 
     _params_for_CNAME = _params_for_single
 
+    def _params_for_CAA(self, values):
+        rdata = []
+
+        for r in values:
+            flags = r['flags']
+            tag = r['tag']
+            value = r['value']
+            rdata.append(f'{flags} {tag} {value}')
+
+        return rdata
+
     def _params_for_MX(self, values):
         rdata = []
 
@@ -451,7 +468,6 @@ class AkamaiProvider(BaseProvider):
     def _build_zone_config(
         self, zone, _type="primary", comment=None, masters=[]
     ):
-
         if self._contractId is None:
             raise NameError("contractId not specified to create zone")
 
@@ -463,7 +479,6 @@ class AkamaiProvider(BaseProvider):
         }
 
     def _get_values(self, data):
-
         try:
             vals = data['values']
         except KeyError:
